# Rename Dirs

A python script to rename multiple directories in a uniform format.

## Why?

I like to keep my PC's folder structure neat and uniform but, during intense hackathons, i mess up my project's folder name format. And so, automating the renaming process made my life a little easier.

## Format Options

* `Example File.txt`

* `Example-File.txt`

* `Example-file.txt`

* `Example_File.txt`

* `example file.txt`

* `example-file.txt`

* `example_file.txt`

## Installation

```bash
pip install rename-dirs
```

## Example

* After installing, run `rename-dirs`
* Enter directory path:
<img width="706" alt="screenshot_enter_dir_path" src="https://user-images.githubusercontent.com/44428198/120315775-53e41080-c2fa-11eb-8bdb-fbcfc813485f.png">

* Choose file name format:
<img width="706" alt="screenshot_file_name_format" src="https://user-images.githubusercontent.com/44428198/120316283-e08ece80-c2fa-11eb-8a7a-42976e163db7.png">

* Enter Y/n for each file/folder:
<img width="762" alt="screenshot_yes_no_file" src="https://user-images.githubusercontent.com/44428198/120315094-9822e100-c2f9-11eb-9472-008185b6606a.png">

* Initial folder structure:
<img width="741" alt="screenshot_initial_folder_structure" src="https://user-images.githubusercontent.com/44428198/120315073-93f6c380-c2f9-11eb-8c60-f81ba8567632.png">

* Final folder structure:
<img width="785" alt="screenshot_final_folder_structure" src="https://user-images.githubusercontent.com/44428198/120315101-99eca480-c2f9-11eb-9146-cb496141d7bd.png">
